==> tesseract_1.02.orig.tar.gz: tesseract-1.02/classify/picofeat.h <==
/******************************************************************************
 **	Filename:    picofeat.h
 **	Purpose:     Definition of pico features.
 **	Author:      Dan Johnson
 **	History:     9/4/90, DSJ, Created.
 **
 **	(c) Copyright Hewlett-Packard Company, 1988.
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
 ** You may obtain a copy of the License at
 ** http://www.apache.org/licenses/LICENSE-2.0
 ** Unless required by applicable law or agreed to in writing, software
 ** distributed under the License is distributed on an "AS IS" BASIS,
 ** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ** See the License for the specific language governing permissions and
 ** limitations under the License.
 ******************************************************************************/
#ifndef   PICOFEAT_H
#define   PICOFEAT_H

/**----------------------------------------------------------------------------
          Include Files and Type Defines
----------------------------------------------------------------------------**/
#include "ocrfeatures.h"
#include "tessclas.h"
#include "fxdefs.h"

typedef enum
{ PicoFeatY, PicoFeatDir, PicoFeatX }
PICO_FEAT_PARAM_NAME;

#define MAX_PICO_FEATURES (1000)

/**----------------------------------------------------------------------------
          Public Function Prototypes
----------------------------------------------------------------------------**/
#define GetPicoFeatureLength()  (PicoFeatureLength)

FEATURE_SET ExtractPicoFeatures(TBLOB *Blob, LINE_STATS *LineStats); 

void InitPicoFXVars(); 

/*
#if defined(__STDC__) || defined(__cplusplus)
# define        _ARGS(s) s
#else
# define        _ARGS(s) ()
#endif*/

/* picofeat.c
FEATURE_SET ExtractPicoFeatures
    _ARGS((BLOB *Blob,
  LINE_STATS *LineStats));

void InitPicoFXVars
    _ARGS((void));

#undef _ARGS
*/
/**----------------------------------------------------------------------------
        Global Data Definitions and Declarations
----------------------------------------------------------------------------**/
extern FEATURE_DESC_STRUCT PicoFeatDesc;
extern FLOAT32 PicoFeatureLength;
#endif

==> tesseract_3.02.02.orig.tar.gz: tesseract-3.02.01/classify/picofeat.h <==
/******************************************************************************
 **	Filename:    picofeat.h
 **	Purpose:     Definition of pico features.
 **	Author:      Dan Johnson
 **	History:     9/4/90, DSJ, Created.
 **
 **	(c) Copyright Hewlett-Packard Company, 1988.
 ** Licensed under the Apache License, Version 2.0 (the "License");
 ** you may not use this file except in compliance with the License.
 ** You may obtain a copy of the License at
 ** http://www.apache.org/licenses/LICENSE-2.0
 ** Unless required by applicable law or agreed to in writing, software
 ** distributed under the License is distributed on an "AS IS" BASIS,
 ** WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 ** See the License for the specific language governing permissions and
 ** limitations under the License.
 ******************************************************************************/
#ifndef   PICOFEAT_H
#define   PICOFEAT_H

/**----------------------------------------------------------------------------
          Include Files and Type Defines
----------------------------------------------------------------------------**/
#include "ocrfeatures.h"
#include "params.h"

// Enum for the order/type of params in IntFeatDesc.
enum IntParams {
  IntX,   // x-position (0-255).
  IntY,   // y-position (0-255).
  IntDir  // Direction (0-255, circular).
};

// Enum for the order/type of params in GeoFeatDesc.
enum GeoParams {
  GeoBottom,   // Bounding box bottom in baseline space (0-255).
  GeoTop,      // Bounding box top in baseline space (0-255).
  GeoWidth,    // Bounding box width in baseline space (0-255).

  GeoCount     // Number of geo features.
};

typedef enum
{ PicoFeatY, PicoFeatDir, PicoFeatX }
PICO_FEAT_PARAM_NAME;

#define MAX_PICO_FEATURES (1000)

/*---------------------------------------------------------------------------
          Variables
----------------------------------------------------------------------------*/

extern double_VAR_H(classify_pico_feature_length, 0.05, "Pico Feature Length");


/**----------------------------------------------------------------------------
          Public Function Prototypes
----------------------------------------------------------------------------**/
#define GetPicoFeatureLength()  (PicoFeatureLength)

FEATURE_SET ExtractIntCNFeatures(TBLOB *Blob, const DENORM& denorm);
FEATURE_SET ExtractIntGeoFeatures(TBLOB *Blob, const DENORM& denorm);

/**----------------------------------------------------------------------------
        Global Data Definitions and Declarations
----------------------------------------------------------------------------**/
extern FLOAT32 PicoFeatureLength;
#endif
